#
# spec file for package libeXosip2
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname libeXosip2-11

Name:           libeXosip2
Version:        4.1.0
Release:        3.3
Summary:        Extended osip2 library
License:        GPL-2.0
Group:          Productivity/Networking/Other
Url:            http://savannah.nongnu.org/projects/exosip/
Source:         http://download.savannah.gnu.org/releases/exosip/%{name}-%{version}.tar.gz
Patch0:         libeXosip2-sslverifypaths.patch
BuildRequires:  glibc-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libosip2) >= 4.1.0
BuildRequires:  pkgconfig(openssl)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Extended library for the osip2 protocol.

%package -n %{soname}
Summary:        Extended osip2 library
Group:          System/Libraries
Provides:       libeXosip2 = %{version}

%description -n %{soname}
Extended library for the osip2 protocol.

%package devel
Summary:        Extended osip2 library
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}
Requires:       glibc-devel
Requires:       pkgconfig(libosip2)
Requires:       pkgconfig(openssl)
Provides:       %{soname}-devel = %{version}

%description devel
Extended library for the osip2 protocol.

%prep
%setup -q
%patch0 -p0

%build
%configure \
  --disable-static \
  --disable-debug
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{soname} -p /sbin/ldconfig

%postun -n %{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/sip_reg

%files -n %{soname}
%defattr(-,root,root)
%{_libdir}/lib*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/eXosip2/*.h
%dir %{_includedir}/eXosip2
%{_libdir}/lib*.so

%changelog
* Sun May 25 2014 fisiu@opensuse.org
- Update to 4.1.0:
  * improve timer and use UPDATE if advertised, INVITE otherwise.
  * improve PRACK support.
  * option to disable automatic BYE answer.
  * option to enable/disable IPv6 per eXosip_t instance.
  * option to disable DNS cache.
  * improve network support for several eXosip_t instance.
    keepalive setting is per instance.
    ipv4/ipv6 setting is per instance.
    improve network setting to avoid conflict upon transport change.
  * fix tcp and tls connect() for slow connection.
  * use TCP_NODELAY on more platform.
  * use Authorization header for 401 // simplify authentication code.
  * minor expires for REGISTER improvments.
  * copy call-info over SUBSCRIBE refresh.
  * allow more TLS error if verification is disabled.
  * fix if NO NAPTR is availble.
  * add support for Windows Phone 8.
  * fix to use cache for TCP and TLS.
  * fix possible leaks on implementation errors.
  * add TSC experimental support.
- eXosip2 (4.0.0)
  * modify configuration APIs to use eXosip_set_option
  * fix bug: do not create new PRACK if it already exist for an answer.
  * update to latest osip // test time compensation for android.
  * use ephemaral port in standard TCP and TLS version.
  * return tid number so that we can match the response event.
  * use system independant time for osip_gettimeofday on unix platform.
  * major API update: several "struct eXosip_t" can be
    handled at the same time. This can be used to have several
    transport layer running at the same time.
  * many tiny other change.
- Rebase libeXosip2-sslverifypaths.patch.
* Mon Apr 28 2014 meissner@suse.com
- libeXosip2-sslverifypaths.patch: set default SSL verify locations (bnc#871099)
- build with -O2 (--disable-debug)
* Fri Jan 25 2013 jengelh@inai.de
- Remove redundant tags/sections from specfile
* Sun Jan 16 2011 seife+obs@b1-systems.com
- update to version 3.5.0
  * a lot of minor change/fix/improvments, sorry for not being
    able to have an history here...
- eXosip2 (3.4.0)
  * handle keep alive for TCP/TLS.
  * fix when receiving additionnal CRLF on reliable transport.
  * modification to allow non-blocking socket for reliable transport. (TLS/TCP)
  * fix tag issue with application where tag is missing.
  * fix Contact header in request within dialog for non-udp protocol.
  * remove 481 auto answer for unsolicited NOTIFY.
  * fix static id range.
  * initial code for TCP fragmentation.
  * osip_list prototypes and warnings fix
  * fix transport matching for redirection using other transport than udp
- eXosip2 (3.3.0)
  * Fix when 200ok include a contact with an empty line parameter.
  * Fix for replaces header longuer than 256 char.
  * Fix SRV record with more than 10 answers.
  * Sort SRV record.
  * Option to disable NAPTR requests.
- eXosip2 (3.2.0)
  * Improve TLS support and add an API for ssl information & files.
  * return new error code for all API.
  * remove automatic answers to PRACK. (must be done in application now)
  * remove automatically outgoing non established susbscriptions.
- packaging stuff:
  * fix spelling errors in descriptions, other rpmlint warnings
  * rename libeXosip2-4 to libeXosip2-6 (changed SONAME)
* Wed Apr  2 2008 hvogel@suse.de
- update to version 3.1.0
  * add AKA authentication
  * improve compliance & flexibility
  * fix building SUBSCRIBE refresh
  * fix compliance issue with refer-to to-tag/from-tag parameters.
  * fix bug for retransmissions or ACK with proxy that resolve
    to several IP.
  * handle the "expires" parameter to update registration interval.
  * handle the "expires" parameter to update publication interval.
  * handle automatically publish refresh,
    and some error codes (423).
* Thu Feb 28 2008 ro@suse.de
- fix build with current libosip2 (MD5... -> osip_MD5...)
* Thu Jan 10 2008 mskibbe@suse.de
- use --disable-static
- detaillize files section
* Tue Dec 18 2007 mskibbe@suse.de
- create package
